require 'rspec/core/formatters/progress_formatter'

require 'rspec_delivery/tracker'
require 'rspec_delivery/message'

module RspecDelivery
	class Formatter < RSpec::Core::Formatters::ProgressFormatter

		def start(example_count)
			RSpec.configuration.post_rspec_endpoint

			@tracker = RspecDelivery::Tracker.new

		rescue NoMethodError => e
			# RSpec.clear_remaining_example_groups
			puts "RSpec Delivery: You must set an endpoint to post to within your RSpec.configuration block found in spec_helper.rb.  Instructions can be found at https://github.com/theef/post_rspec. \nRSpec Error Message: #{e} \n\n"
			abort
		end

		def example_group_started(example_group)
		end

		def example_group_finished(example_group)
		end

		def example_started(example)
		end

		def example_passed(example)
			@tracker.add example
			super(example)
		end

		def example_pending(example)
			@tracker.add example
			super(example)
		end

		def example_failed(example)
			@tracker.add example
			super(example)
		end

		def message(message)
		end

		def stop
		end

		def start_dump()
		end

		def dump_pending()
		end

		def dump_failures()
		end

		def dump_summary(duration, example_count, failure_count, pending_count)

			endpoint = RSpec.configuration.post_rspec_endpoint

			unless endpoint.blank?
				rspec_data = {
					duration: duration,
					example_count: example_count,
					failure_count: failure_count,
					pending_count: pending_count
				}

				message = RspecDelivery::Message.new(rspec_data)
				message.tracker_data = @tracker
				message.send endpoint

				super(duration, example_count, failure_count, pending_count)
			end

		rescue NoMethodError => e
			puts "\n\nRSpec error: #{e}"
		end

		####

		def seed(seed)
		end

		def close()
		end

	end
end